package com.appiancorp.suiteapi.process;

public class TaskSummary {
  
  /**
   * A status indicating that a task's initialization is complete and the task is ready to
   * be accepted, but no user has accepted it yet.
   */
  public static final Integer TASK_STATUS_ASSIGNED = new Integer(0);

  /**
   * A task receives this status when it is accepted by a user.
   */
  public static final Integer TASK_STATUS_ACCEPTED = new Integer(1);

  /**
   * A final status indicating that a task has been completed.
   */
  public static final Integer TASK_STATUS_COMPLETED = new Integer(2);

  /**
   * A status indicating that a task has been created but its initialization has not yet
   * begun. Spawned tasks that execute sequentially have this status until the preceding
   * task in the sequence is completed.
   */
  public static final Integer TASK_STATUS_NOT_STARTED = new Integer(3);

  /**
   * A final status indicating that a task has been canceled.
   */
  public static final Integer TASK_STATUS_CANCELLED = new Integer(4);

  /**
   * A status indicating that a task has been paused.
   */
  public static final Integer TASK_STATUS_PAUSED = new Integer(5);

  /**
   * A status indicating that an unattended task has finished initialization and is either
   * executing or about to be executed.
   */
  public static final Integer TASK_STATUS_UNATTENDED = new Integer(6);

  /**
   * This status is not used.
   */
  @Deprecated
  public static final Integer TASK_STATUS_ABORTED = new Integer(7);

  /**
   * A status indicating that a task has been paused by exception.
   */
  public static final Integer TASK_STATUS_PAUSED_BY_EXCEPTION = new Integer(8);

  /**
   * A status indicating that a legacy web service activity has been submitted.
   */
  public static final Integer TASK_STATUS_SUBMITTED = new Integer(9);

  /**
   * A status indicating that a legacy web service activity is running.
   */
  public static final Integer TASK_STATUS_RUNNING = new Integer(10);

  /**
   * A status indicating that an error has occurred during execution of a legacy web
   * service activity.
   */
  public static final Integer TASK_STATUS_ERROR = new Integer(11);

  /**
   * A final status indicating that a task has been skipped. A task is skipped when its
   * exception flow is taken.
   */
  public static final Integer TASK_STATUS_SKIPPED = new Integer(14);

  //NOTE: because the definition of the bean fields for TaskSummary differs
  //between exec and analytics in k, no SORT_BY_XXX fields can be added
  //above index 19, the last index at which the fields match
  public static final Integer SORT_BY_NAME                 = new Integer(0);
  public static final Integer SORT_BY_STATUS               = new Integer(1);
  public static final Integer SORT_BY_PRIORITY_NAME        = new Integer(2);
  public static final Integer SORT_BY_ASSIGNED_TIME        = new Integer(3);
  public static final Integer SORT_BY_ACCEPTED_TIME        = new Integer(4);
  public static final Integer SORT_BY_ELAPSED_MILLISECONDS = new Integer(5);
  public static final Integer SORT_BY_COMPLETED_TIME       = new Integer(6);
  public static final Integer SORT_BY_PROCESS_NAME         = new Integer(7);
  public static final Integer SORT_BY_PROCESS_INITIATOR    = new Integer(8);
  public static final Integer SORT_BY_ID                   = new Integer(9);
  public static final Integer SORT_BY_DESCRIPTION          = new Integer(10);
  public static final Integer SORT_BY_OWNERS               = new Integer(11);
  public static final Integer SORT_BY_PROCESSID            = new Integer(13);
  public static final Integer SORT_BY_ACCEPTMODE           = new Integer(14);
  public static final Integer SORT_BY_ONE_USER_ASSIGNED    = new Integer(15); 
  /**
   * @deprecated Use {@link #SORT_BY_ELAPSED_MILLISECONDS} instead.
   */
  @Deprecated
  public static final Integer SORT_BY_ELAPSED              = new Integer(5);
  /**
   * @deprecated Use {@link #SORT_BY_PRIORITY_NAME} instead, which produces the same results.
   */
  @Deprecated
  public static final Integer SORT_BY_PRIORITY_ID          = new Integer(2);
}
