package com.appiancorp.suiteapi.type;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import com.appiancorp.type.NamedType;
import com.appiancorp.type.TypeRef;
// GWT-compatible AND GWT-RPC serializable
public class NamedTypedValue extends TypedValue implements NamedType  {

  private String name;

  public NamedTypedValue() {
  }

  public NamedTypedValue(TypedValue tv) {
    super(tv);
  }

  public NamedTypedValue(NamedTypedValue ntv) {
    this(ntv, ntv.getName());
  }

  public NamedTypedValue(TypedValue tv, String name) {
    super(tv);
    this.name = name;
  }

  public NamedTypedValue(Long instanceType) {
    super(instanceType);
  }

  public NamedTypedValue(String name, Long instanceType) {
    this(instanceType);
    setName(name);
  }

  /**
   * Creates an instance with the given name, type and value.
   *
   * @param name the name
   * @param instanceType the type id
   * @param value the value
   */
  public NamedTypedValue(String name, Long instanceType, Object value) {
    super(instanceType, value);
    this.name = name;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  @Override
  public boolean equals(Object o) {
    if (!(o instanceof NamedTypedValue)) {
      return false;
    }
    NamedTypedValue n = (NamedTypedValue)o;
    return (name == null ? n.getName() == null : name.equals(n.getName())) && super.equals(n);
  }

  @Override
  public int hashCode() {
    int result = 17;
    result = 37*result + super.hashCode();
    result = 37*result + (name == null ? 0 : name.hashCode());
    return result;
  }

  @Override
  public String toString() {
    return "name="+name + "," + super.toString();
  }

  @Override
  public NamedTypedValue clone() {
    NamedTypedValue clone = new NamedTypedValue();
    clone.setName(getName());
    clone.setTypeRef(new TypeRef(getTypeRef()));
    clone.setValue(getValue());
    return clone;
  }

  public static NamedTypedValue findNtvByName(NamedTypedValue[] ntvs, String name) {
    int propertyIdx = findNtvIndexByName(ntvs, name);
    return propertyIdx < 0 ? null : ntvs[propertyIdx];
  }

  public static int findNtvIndexByName(NamedTypedValue[] ntvs, String name) {
    if (ntvs == null) {
      return -1;
    }
    for (int i = 0; i < ntvs.length; i++) {
      NamedTypedValue ntv = ntvs[i];
      if (ntv.getName().equals(name)) {
        return i;
      }
    }
    return -1;
  }

  public static List<String> getNtvNames(Collection<? extends NamedTypedValue> ntvs) {
    List<String> ntvNames = new ArrayList<String>();
    for (NamedTypedValue ntv : ntvs) {
      ntvNames.add(ntv.getName());
    }
    return ntvNames;
  }


}