package com.appiancorp.suiteapi.type;

import java.io.Serializable;
import java.util.Arrays;

import com.appiancorp.suiteapi.common.DeepCloneable;
import com.appiancorp.type.HasTypeRef;
import com.appiancorp.type.TypeRef;
// GWT-compatible AND GWT-RPC serializable
public class TypedValue implements Serializable, HasTypeRef, DeepCloneable {

  private TypeRef typeRef = new TypeRef();
  private transient Object value;

  public TypedValue() {
  }

  public TypedValue(TypedValue tv) {
    if (tv == null) {
      throw new NullPointerException("Null TypedValue");
    }
    setInstanceType(tv.getInstanceType());
    setValue(tv.getValue());
  }

  public TypedValue(Long instanceType) {
    this(instanceType, null);
  }

  public TypedValue(Long instanceType, Object value) {
    setInstanceType(instanceType);
    setValue(value);
  }

  public void setInstanceType(Long instanceType) {
    if (typeRef == null) {
      typeRef = new TypeRef();
    }
    typeRef.setId(instanceType);
  }

  public Long getInstanceType() {
    if (typeRef == null) {
      return null;
    }
    return typeRef.getId();
  }

  public TypeRef getTypeRef() {
    return typeRef;
  }

  public void setTypeRef(TypeRef typeRef) {
    this.typeRef = typeRef;
  }

  public Object getValue() {
    return value;
  }

  public void setValue(Object value) {
    this.value = value;
  }

  @Override
  public int hashCode() {
    int result = 17;
    result = 37*result + (typeRef == null ? 0 : typeRef.hashCode());
    result = 37*result + (value == null ? 0 : value.hashCode());
    return result;
  }

  @Override
  public boolean equals(Object o) {
    if (!(o instanceof TypedValue)) {
      return false;
    }
    TypedValue other = (TypedValue)o;
    return other.typeRef.equals(this.typeRef) &&
      isEquals(other.value, this.value);
  }

  private boolean isEquals(Object l, Object r) {
    if (l == null) {
      return r == null;
    } else if (r == null) {
      return l == null;
    } else if (l.getClass().isArray() && r.getClass().isArray()) {
      return Arrays.deepEquals((Object[])l, (Object[])r);
    } else {
      return l.equals(r);
    }
  }

  @Override
  public String toString() {
    return "TypedValue[it="+typeRef.getId()+",v="+value+"]";
  }

  @Override
  public TypedValue clone() {
    TypedValue clone = new TypedValue();
    clone.setTypeRef(new TypeRef(getTypeRef()));
    clone.setValue(getValue());
    return clone;
  }

}