package com.appiancorp.suiteapi.common;

import javax.xml.bind.annotation.XmlTransient;

import com.appiancorp.suiteapi.common.LocalId;
import com.appiancorp.suiteapi.common.LocalStringId;

//No GWT-RPC serialization is supported.
public class LocalObject implements LocalId, LocalStringId  {

  public static final int PERSONALIZATION_BASE = 0x00001000;
  public static final int LO_USER = PERSONALIZATION_BASE + 1;
  public static final Integer TYPE_USER = new Integer(LO_USER);
  private static final long serialVersionUID = -5221009684376584215l;
  private static final int DEFAULT_HASH = 17;
  private static final int DEFAULT_RESULT = 37;
  private Long _id;
  private String _stringId;
  private Integer _type;

  /**
   * Constructor that constructs an empty local object.
   */
  public LocalObject() {
  }

  /**
   * Constructor that constructs from a given type and id.
   *
   * @param type_
   *          Use a constant from an <code>ObjectTypeMapping</code>.
   * @param id_ ID of type Long for object to constructor
   */
  public LocalObject(Integer type_, Long id_) {
    setType(type_);
    setId(id_);
  }

  /**
   * Constructor that constructs from a type and String id.
   *
   * @param type_
   *          Use a constant from an <code>ObjectTypeMapping</code>.
   * @param id_ String ID of the object to construct
   */
  public LocalObject(Integer type_, String id_) {
    setType(type_);
    setStringId(id_);
  }

  /**
   * Returns the ID of this <code>LocalObject</code>.
   *
   * @return ID of this object
   * @see #setId(Long)
   */
  public Long getId() {
    return _id;
  }

  /**
   * Sets the ID of this <code>LocalObject</code>.
   * @param p_ ID to set
   * @see #getId()
   */
  public void setId(Long p_) {
    _id = p_;
  }

  /**
   * Gets the type of this <code>LocalObject</code>. Should return a constant
   * from <code>ObjectTypeMapping</code>.
   *
   * @return Type of this object
   * @see #setType(Integer)
   */
  public Integer getType() {
    return _type;
  }

  /**
   * Set the type of this <code>LocalObject</code>. Use a constant from
   * <code>ObjectTypeMapping</code>.
   *
   * @param p_ Type of this object to set
   * @see #getType()
   */
  public void setType(Integer p_) {
    _type = p_;
  }

  /**
   * Returns the String Id of this <code>LocalObject</code>.
   *
   * @return Returns the string Id.
   * @see #setStringId(String)
   */
  public String getStringId() {
    return _stringId;
  }

  /**
   * Sets the String ID of this <code>LocalObject</code>.
   * @param stringId_  The string Id to set.
   * @see #getStringId()
   */
  public void setStringId(String stringId_) {
    _stringId = stringId_;
  }

  /**
   * Returns whether the <code>LocalObject</code> been passed is equal to this
   * <code>LocalObject</code>.
   * @param o_ the reference object with which to compare.
   * @return <code>true</code> if both objects are equal, otherwise
   * <code>false</code>
   */
  @Override
  public boolean equals(Object o_) {
    if (o_ == this) {
      return true;
    }

    if (o_ == null) {
      return false;
    }

    if (!(o_ instanceof LocalObject)) {
      return false;
    }

    LocalObject localObject = (LocalObject) o_;

    Integer type = localObject.getType();
    boolean typeCheck = type != null ? type.equals(_type) : true;

    if (TYPE_USER.equals(_type)) {
      boolean stringCheck = false;

      if ((_stringId == null) && (localObject.getStringId() == null)) {
        stringCheck = true;
      } else if (
        (_stringId != null) && _stringId.equals(localObject.getStringId())) {
        stringCheck = true;
      }

      return stringCheck && typeCheck;
    } else {
      boolean idCheck = false;

      if ((_id == null) && (localObject.getId() == null)) {
        idCheck = true;
      } else if ((_id != null) && _id.equals(localObject.getId())) {
        idCheck = true;
      }

      return (typeCheck && idCheck);
    }
  }

  /**
   * Returns a hash code value for the object. This method is supported for the
   * benefit of hashtables such as those provided by {@link java.util.Hashtable}.
   * @return a hash code value for this object
   */
  @Override
  public int hashCode() {
    int result = DEFAULT_RESULT;

    if (TYPE_USER.equals(_type)) {
      result =
        (DEFAULT_RESULT * result)
          + ((_stringId != null) ? _stringId.hashCode() : DEFAULT_HASH);
    } else {
      result =
        (DEFAULT_RESULT * result)
          + ((_id != null) ? _id.hashCode() : DEFAULT_HASH);
    }

    result += ((_type != null) ? _type.hashCode() : DEFAULT_HASH);

    return result;
  }
  /**
   * Returns a string representation of the <code>LocalObject</code>.In general,
   * the toString method returns a string that "textually represents" this
   * object.
   * @return String representation of the object
   */
  @Override
  public String toString() {
    return "" + _type + " " + (_id != null ? _id : _stringId);
  }

  /**
   * A LocalObject may be null by containing a null type, or null object within the type.
   *
   * @return true if type or id/stringId is null
   */
  @XmlTransient//MOXy-BUG
  public boolean isNull() {
    if(_type == null) {
      return true;
    }
    if(_id != null) {
      return false;
    }
    if(_stringId == null) {
      return true;
    }
    return _stringId.length() == 0;
  }

}
