package com.appiancorp.suiteapi.common;

import com.appiancorp.suiteapi.common.LocalObject;


/**
 * Enables mapping between Appian type objects and their corresponding type
 * constants. Appian Type objects (also referred to as "first-class" or
 * "Appian" objects) are defined for all top-level data structures specific
 * in the product, such as Forums, Documents, Process Models, etc.
 *
 * @author derek.richardson
 * @author nikita.dubrovsky
 */
public class ObjectTypeMapping {
  public static final int PORTAL_BASE = 0x00000000;
  public static final int PERSONALIZATION_BASE = 0x00001000;
  public static final int FORUMS_BASE = 0x00002000;
  public static final int COLLABORATION_BASE = 0x00003000;
  public static final int DYNAMIC_BASE = 0x10000000;
  public static final int PROCESS_BASE = 0x00005000;

  /** Portlet type. */
  public static final int LO_PORTLET=PORTAL_BASE + 0;
  public static final Integer TYPE_PORTLET = new Integer(LO_PORTLET);

  /** Page type. */
  public static final int LO_PAGE=PORTAL_BASE + 1;
  public static final Integer TYPE_PAGE = new Integer(LO_PAGE);

  /** Link type. */
  public static final int LO_LINK=PORTAL_BASE + 2;
  public static final Integer TYPE_LINK = new Integer(LO_LINK);

  /** Group type. */
  public static final int LO_GROUP=PERSONALIZATION_BASE + 0;
  public static final Integer TYPE_GROUP =
    new Integer(LO_GROUP);

  /** User type. */
  public static final int LO_USER=PERSONALIZATION_BASE + 1;
  public static final Integer TYPE_USER =
    new Integer(LO_USER);

  /** Group Type type. */
  public static final int LO_GROUP_TYPE=PERSONALIZATION_BASE + 3;
  public static final Integer TYPE_GROUP_TYPE =
    new Integer(LO_GROUP_TYPE);

  /** Email Address type. */
  public static final int LO_EMAIL_ADDRESS=PERSONALIZATION_BASE + 2;
  public static final Integer TYPE_EMAIL_ADDRESS =
    new Integer(LO_EMAIL_ADDRESS);

  /** Forum type. */
  public static final int LO_FORUM= FORUMS_BASE + 0;
  public static final Integer TYPE_FORUM = new Integer(LO_FORUM);

  /** Thread type. */
  public static final int LO_DISCUSSION_THREAD=FORUMS_BASE + 1;
  public static final Integer TYPE_DISCUSSION_THREAD =
    new Integer(LO_DISCUSSION_THREAD);

  /** Message type. */
  public static final int LO_MESSAGE=FORUMS_BASE + 2;
  public static final Integer TYPE_MESSAGE = new Integer(LO_MESSAGE);

  /** Document type. */
  public static final int LO_DOCUMENT=COLLABORATION_BASE + 0;
  public static final Integer TYPE_DOCUMENT =
    new Integer(LO_DOCUMENT);

  /** Collaboration folder type. */
  public static final int LO_FOLDER=COLLABORATION_BASE + 1;
  public static final Integer TYPE_FOLDER =
    new Integer(LO_FOLDER);

  /** Knowledge center type. */
  public static final int LO_KNOWLEDGE_CENTER=COLLABORATION_BASE + 2;
  public static final Integer TYPE_KNOWLEDGE_CENTER =
    new Integer(LO_KNOWLEDGE_CENTER);

  /** Collaboration community type. */
  public static final int LO_COMMUNITY=COLLABORATION_BASE + 3;
  public static final Integer TYPE_COMMUNITY =
    new Integer(LO_COMMUNITY);

  /** Content community type. */
  public static final int LO_CONTENT=COLLABORATION_BASE + 8;
  public static final Integer TYPE_CONTENT =
    new Integer(LO_CONTENT);

  /** Process model type. */
  public static final int LO_BPM_PROCESS_MODEL=PROCESS_BASE + 0;
  public static final Integer TYPE_BPM_PROCESS_MODEL =
    new Integer(LO_BPM_PROCESS_MODEL);

  /** Process type. */
  public static final int LO_BPM_PROCESS=PROCESS_BASE + 1;
  public static final Integer TYPE_BPM_PROCESS = new Integer(LO_BPM_PROCESS);

  /** Task type. */
  public static final int LO_BPM_TASK=PROCESS_BASE + 2;
  public static final Integer TYPE_BPM_TASK = new Integer(LO_BPM_TASK);

  /** Node type. */
  public static final int LO_BPM_NODE=PROCESS_BASE + 3;
  public static final Integer TYPE_BPM_NODE = new Integer(LO_BPM_NODE);

  /**
   * Returns the name of a {@link LocalObject} type. The name is just a String (not
   * internationalized) that can be displayed in logs; the name value has no special
   * meaning (it's not a key) and can change in the future.
   *
   * @param type A {@link LocalObject#getType() LocalObject type} (which can be any
   * one of the LO_XXX constants on this class).
   * @return The name of the given type.
   */
  public static String getTypeName(int type) {
    switch (type) {
      case LO_PORTLET: return "PORTLET";
      case LO_PAGE: return "PAGE";
      case LO_LINK: return "LINK";
      case LO_GROUP: return "GROUP";
      case LO_USER: return "USER";
      case LO_GROUP_TYPE: return "GROUP_TYPE";
      case LO_EMAIL_ADDRESS: return "EMAIL_ADDRESS";
      case LO_FORUM: return "FORUM";
      case LO_DISCUSSION_THREAD: return "DISCUSSION_THREAD";
      case LO_MESSAGE: return "MESSAGE";
      case LO_DOCUMENT: return "DOCUMENT";
      case LO_FOLDER: return "FOLDER";
      case LO_KNOWLEDGE_CENTER: return "KNOWLEDGE_CENTER";
      case LO_COMMUNITY: return "COMMUNITY";
      case LO_CONTENT: return "CONTENT";
      case LO_BPM_PROCESS_MODEL: return "PROCESS_MODEL";
      case LO_BPM_PROCESS: return "PROCESS";
      case LO_BPM_TASK: return "TASK";
      case LO_BPM_NODE: return "NODE";
      default: return "LocalObject["+type+"]";
    }
  }
}
